=======
History
=======

0.1.0 (2019-05-16)
------------------

* First release on PyPI.


0.1.1 (2019-05-17)
------------------

* Minor precision bug fixes.


0.1.2 (2019-05-19)
------------------

* mass2_batch release for efficient large time series searching.

0.1.3 (2019-05-19)
------------------

* top_k_motifs - find the top k similar subsequences given a distance profile.
* top_k_discords - find the top k dissimilar subsequences given a distance profile.